==> axonius_api_client-4.10.9-py2.py3-none-any.whl: axonius_api_client/api/json_api/password_reset.py <==
# -*- coding: utf-8 -*-
"""Models for API requests & responses."""
import dataclasses
from typing import Optional, Type, Union

from ...http import Http
from .base import BaseModel, BaseSchema
from .generic import BoolValue


@dataclasses.dataclass
class CreateRequest(BaseModel):
    """Pass."""

    user_id: str
    user_name: str


@dataclasses.dataclass
class SendRequest(BaseModel):
    """Pass."""

    email: str
    user_id: str
    invite: bool = False


@dataclasses.dataclass
class SendResponse(BaseModel):
    """Pass."""

    user_name: str


@dataclasses.dataclass
class ValidateRequest(BaseModel):
    """Pass."""

    token: str

    def dump_request_params(self, **kwargs) -> Optional[dict]:
        """Pass."""
        return None


@dataclasses.dataclass
class ValidateResponse(BoolValue):
    """Pass."""

    @classmethod
    def load_response(
        cls,
        data: Union[dict, list],
        http: Http,
        api_endpoint,
        schema_cls: Optional[Type[BaseSchema]] = None,
        **kwargs,
    ):
        """Pass."""
        data = {"value": data["valid"]}
        return super().load_response(
            data=data, http=http, schema_cls=schema_cls, api_endpoint=api_endpoint, **kwargs
        )
        # PBUG: forced into BoolValue model

    @staticmethod
    def get_schema_cls() -> Optional[Type[BaseSchema]]:
        """Pass."""
        return None


@dataclasses.dataclass
class UseRequest(BaseModel):
    """Pass."""

    token: str
    password: str


@dataclasses.dataclass
class UseResponse(BaseModel):
    """Pass."""

    user_name: str

==> axonius_api_client-4.20.2-py2.py3-none-any.whl: axonius_api_client/api/json_api/password_reset.py <==
# -*- coding: utf-8 -*-
"""Models for API requests & responses."""
import dataclasses
from typing import Optional, Type, Union

from ...http import Http
from .base import BaseModel, BaseSchema
from .generic import BoolValue


@dataclasses.dataclass
class CreateRequest(BaseModel):
    """Pass."""

    user_id: str
    user_name: str

    @staticmethod
    def get_schema_cls() -> Optional[Type[BaseSchema]]:
        """Pass."""
        return None


@dataclasses.dataclass
class SendRequest(BaseModel):
    """Pass."""

    email: str
    user_id: str
    invite: bool = False

    @staticmethod
    def get_schema_cls() -> Optional[Type[BaseSchema]]:
        """Pass."""
        return None


@dataclasses.dataclass
class SendResponse(BaseModel):
    """Pass."""

    user_name: str

    @staticmethod
    def get_schema_cls() -> Optional[Type[BaseSchema]]:
        """Pass."""
        return None


@dataclasses.dataclass
class ValidateRequest(BaseModel):
    """Pass."""

    token: str

    def dump_request_params(self, **kwargs) -> Optional[dict]:
        """Pass."""
        return None

    @staticmethod
    def get_schema_cls() -> Optional[Type[BaseSchema]]:
        """Pass."""
        return None


@dataclasses.dataclass
class ValidateResponse(BoolValue):
    """Pass."""

    @classmethod
    def load_response(
        cls,
        data: Union[dict, list],
        http: Http,
        schema_cls: Optional[Type[BaseSchema]] = None,
        **kwargs
    ):
        """Pass."""
        data = {"value": data["valid"]}
        return super().load_response(data=data, http=http, schema_cls=schema_cls, **kwargs)
        # PBUG: forced into BoolValue model

    @staticmethod
    def get_schema_cls() -> Optional[Type[BaseSchema]]:
        """Pass."""
        return None


@dataclasses.dataclass
class UseRequest(BaseModel):
    """Pass."""

    token: str
    password: str

    @staticmethod
    def get_schema_cls() -> Optional[Type[BaseSchema]]:
        """Pass."""
        return None


@dataclasses.dataclass
class UseResponse(BaseModel):
    """Pass."""

    user_name: str

    @staticmethod
    def get_schema_cls() -> Optional[Type[BaseSchema]]:
        """Pass."""
        return None
